"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict
from typing_extensions import NotRequired, TypedDict


class CybersourceAntiFraudOptionsTypedDict(TypedDict):
    merchant_defined_data: NotRequired[Nullable[Dict[str, str]]]
    r"""A list of merchant defined data to be passed to the Cybersource Decision Manager API. Each key needs to be a numeric string."""
    meta_key_merchant_id: NotRequired[Nullable[str]]
    r"""The merchant ID to use for this transaction. This requires a meta key to be set up for use with Cybersource Decision Manager, and this overrides the connector configuration."""
    shipping_method: NotRequired[Nullable[str]]
    r"""The shipping method for this transaction."""


class CybersourceAntiFraudOptions(BaseModel):
    merchant_defined_data: OptionalNullable[Dict[str, str]] = UNSET
    r"""A list of merchant defined data to be passed to the Cybersource Decision Manager API. Each key needs to be a numeric string."""

    meta_key_merchant_id: OptionalNullable[str] = UNSET
    r"""The merchant ID to use for this transaction. This requires a meta key to be set up for use with Cybersource Decision Manager, and this overrides the connector configuration."""

    shipping_method: OptionalNullable[str] = UNSET
    r"""The shipping method for this transaction."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["merchant_defined_data", "meta_key_merchant_id", "shipping_method"]
        )
        nullable_fields = set(
            ["merchant_defined_data", "meta_key_merchant_id", "shipping_method"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
