"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .threedsecurescenarioconditions import (
    ThreeDSecureScenarioConditions,
    ThreeDSecureScenarioConditionsTypedDict,
)
from .threedsecurescenariooutcome import (
    ThreeDSecureScenarioOutcome,
    ThreeDSecureScenarioOutcomeTypedDict,
)
from gr4vy.types import BaseModel
from typing_extensions import TypedDict


class ThreeDSecureScenarioCreateTypedDict(TypedDict):
    conditions: ThreeDSecureScenarioConditionsTypedDict
    outcome: ThreeDSecureScenarioOutcomeTypedDict


class ThreeDSecureScenarioCreate(BaseModel):
    conditions: ThreeDSecureScenarioConditions

    outcome: ThreeDSecureScenarioOutcome
