"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from pydantic import model_serializer
from typing import Literal, Union
from typing_extensions import NotRequired, TypedDict


PurposeCode = Union[
    Literal[
        "mortgage",
        "utility",
        "loan",
        "dependant_support",
        "gambling",
        "retail",
        "salary",
        "personal",
        "government",
        "pension",
        "tax",
        "other",
    ],
    UnrecognizedStr,
]


class GoCardlessOptionsTypedDict(TypedDict):
    purpose_code: NotRequired[Nullable[PurposeCode]]
    r"""Specifies the high-level purpose of a mandate and/or payment using a set of pre-defined categories. Required for the PayTo scheme, optional for all others"""


class GoCardlessOptions(BaseModel):
    purpose_code: OptionalNullable[PurposeCode] = UNSET
    r"""Specifies the high-level purpose of a mandate and/or payment using a set of pre-defined categories. Required for the PayTo scheme, optional for all others"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["purpose_code"])
        nullable_fields = set(["purpose_code"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
