"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, UNSET_SENTINEL
from gr4vy.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class CryptogramTypedDict(TypedDict):
    cryptogram: str
    r"""The cryptogram of the network token."""
    type: Literal["network-token-cryptogram"]
    r"""Always `network-token-cryptogram`."""


class Cryptogram(BaseModel):
    cryptogram: str
    r"""The cryptogram of the network token."""

    TYPE: Annotated[
        Annotated[
            Optional[Literal["network-token-cryptogram"]],
            AfterValidator(validate_const("network-token-cryptogram")),
        ],
        pydantic.Field(alias="type"),
    ] = "network-token-cryptogram"
    r"""Always `network-token-cryptogram`."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["type"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
