"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict


class NuveiPSEOptionsTypedDict(TypedDict):
    user_type: NotRequired[Nullable[str]]
    r"""Customer type (\"N\" for persona natural, \"J\" for persona jurídica)"""
    user_fis_number: NotRequired[Nullable[str]]
    r"""Customer’s document type"""
    fiscal_number: NotRequired[Nullable[str]]
    r"""Customer’s document number"""
    bank_code: NotRequired[Nullable[str]]
    r"""The bank code of the selected bank"""


class NuveiPSEOptions(BaseModel):
    user_type: Annotated[OptionalNullable[str], pydantic.Field(alias="userType")] = (
        UNSET
    )
    r"""Customer type (\"N\" for persona natural, \"J\" for persona jurídica)"""

    user_fis_number: Annotated[
        OptionalNullable[str], pydantic.Field(alias="userFisNumber")
    ] = UNSET
    r"""Customer’s document type"""

    fiscal_number: Annotated[
        OptionalNullable[str], pydantic.Field(alias="fiscalNumber")
    ] = UNSET
    r"""Customer’s document number"""

    bank_code: Annotated[OptionalNullable[str], pydantic.Field(alias="bankCode")] = (
        UNSET
    )
    r"""The bank code of the selected bank"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["userType", "userFisNumber", "fiscalNumber", "bankCode"])
        nullable_fields = set(["userType", "userFisNumber", "fiscalNumber", "bankCode"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
