"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .forterantifraudoptionscartitem import (
    ForterAntiFraudOptionsCartItem,
    ForterAntiFraudOptionsCartItemTypedDict,
)
from .forterantifraudoptionsdiscount import (
    ForterAntiFraudOptionsDiscount,
    ForterAntiFraudOptionsDiscountTypedDict,
)
from gr4vy.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from pydantic import model_serializer
from typing import List, Literal, Union
from typing_extensions import NotRequired, TypedDict


ForterAntiFraudOptionsDeliveryType = Union[
    Literal[
        "DIGITAL",
        "PHYSICAL",
        "HYBRID",
    ],
    UnrecognizedStr,
]


class ForterAntiFraudOptionsTypedDict(TypedDict):
    delivery_type: NotRequired[Nullable[ForterAntiFraudOptionsDeliveryType]]
    r"""The delivery type"""
    delivery_method: NotRequired[Nullable[str]]
    r"""The delivery method"""
    is_guest_buyer: NotRequired[Nullable[bool]]
    r"""Defines if this payment is made using guest checkout."""
    cart_items: NotRequired[Nullable[List[ForterAntiFraudOptionsCartItemTypedDict]]]
    r"""A list of cart items details to pass to the Forter API."""
    total_discount: NotRequired[Nullable[ForterAntiFraudOptionsDiscountTypedDict]]
    r"""Information about the discount applied to this order."""


class ForterAntiFraudOptions(BaseModel):
    delivery_type: OptionalNullable[ForterAntiFraudOptionsDeliveryType] = UNSET
    r"""The delivery type"""

    delivery_method: OptionalNullable[str] = UNSET
    r"""The delivery method"""

    is_guest_buyer: OptionalNullable[bool] = UNSET
    r"""Defines if this payment is made using guest checkout."""

    cart_items: OptionalNullable[List[ForterAntiFraudOptionsCartItem]] = UNSET
    r"""A list of cart items details to pass to the Forter API."""

    total_discount: OptionalNullable[ForterAntiFraudOptionsDiscount] = UNSET
    r"""Information about the discount applied to this order."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "delivery_type",
                "delivery_method",
                "is_guest_buyer",
                "cart_items",
                "total_discount",
            ]
        )
        nullable_fields = set(
            [
                "delivery_type",
                "delivery_method",
                "is_guest_buyer",
                "cart_items",
                "total_discount",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
