"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .userstatus import UserStatus
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from gr4vy.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AuditLogEntryUserTypedDict(TypedDict):
    name: str
    r"""The name of the user."""
    is_staff: bool
    r"""Whether this is a Gr4vy staff user."""
    status: UserStatus
    type: Literal["user"]
    r"""Always `user`."""
    id: NotRequired[Nullable[str]]
    r"""The ID of the user."""
    email_address: NotRequired[Nullable[str]]
    r"""The email address for this user."""


class AuditLogEntryUser(BaseModel):
    name: str
    r"""The name of the user."""

    is_staff: bool
    r"""Whether this is a Gr4vy staff user."""

    status: UserStatus

    TYPE: Annotated[
        Annotated[Optional[Literal["user"]], AfterValidator(validate_const("user"))],
        pydantic.Field(alias="type"),
    ] = "user"
    r"""Always `user`."""

    id: OptionalNullable[str] = UNSET
    r"""The ID of the user."""

    email_address: OptionalNullable[str] = UNSET
    r"""The email address for this user."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["type", "id", "email_address"])
        nullable_fields = set(["id", "email_address"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
