"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from pydantic import model_serializer
from typing import Literal, Union
from typing_extensions import NotRequired, TypedDict


VaultPaymentMethodCriteria = Union[
    Literal[
        "ALWAYS",
        "ON_SUCCESSFUL_TRANSACTION",
    ],
    UnrecognizedStr,
]


class BraintreeDynamicDataFieldsOptionsTypedDict(TypedDict):
    three_ds_auth_status: NotRequired[Nullable[str]]
    r"""Passes the 3DS status to the Braintree API using `customFields` with the key set to the value of `three_ds_auth_status`"""
    purchase_order_number: NotRequired[Nullable[str]]
    r"""Passes the `transaction.purchaseOrderNumber` field when creating a new transaction."""
    vault_payment_method_criteria: NotRequired[Nullable[VaultPaymentMethodCriteria]]
    r"""Passes the `vaultPaymentMethodCriteria` field when creating a new transaction."""


class BraintreeDynamicDataFieldsOptions(BaseModel):
    three_ds_auth_status: OptionalNullable[str] = UNSET
    r"""Passes the 3DS status to the Braintree API using `customFields` with the key set to the value of `three_ds_auth_status`"""

    purchase_order_number: OptionalNullable[str] = UNSET
    r"""Passes the `transaction.purchaseOrderNumber` field when creating a new transaction."""

    vault_payment_method_criteria: OptionalNullable[VaultPaymentMethodCriteria] = UNSET
    r"""Passes the `vaultPaymentMethodCriteria` field when creating a new transaction."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "three_ds_auth_status",
                "purchase_order_number",
                "vault_payment_method_criteria",
            ]
        )
        nullable_fields = set(
            [
                "three_ds_auth_status",
                "purchase_order_number",
                "vault_payment_method_criteria",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
