"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict


class TrustlyOptionsTypedDict(TypedDict):
    refresh_split_token: NotRequired[Nullable[bool]]
    r"""Indicates to Gr4vy whether or not the stored Trustly agreement needs refreshing."""


class TrustlyOptions(BaseModel):
    refresh_split_token: Annotated[
        OptionalNullable[bool], pydantic.Field(alias="refreshSplitToken")
    ] = UNSET
    r"""Indicates to Gr4vy whether or not the stored Trustly agreement needs refreshing."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["refreshSplitToken"])
        nullable_fields = set(["refreshSplitToken"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
