"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .paymentservice import PaymentService, PaymentServiceTypedDict
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class PaymentServicesTypedDict(TypedDict):
    items: List[PaymentServiceTypedDict]
    r"""A list of items returned for this request."""
    limit: NotRequired[int]
    r"""The number of items for this page."""
    next_cursor: NotRequired[Nullable[str]]
    r"""The cursor pointing at the next page of items."""
    previous_cursor: NotRequired[Nullable[str]]
    r"""The cursor pointing at the previous page of items."""


class PaymentServices(BaseModel):
    items: List[PaymentService]
    r"""A list of items returned for this request."""

    limit: Optional[int] = 20
    r"""The number of items for this page."""

    next_cursor: OptionalNullable[str] = UNSET
    r"""The cursor pointing at the next page of items."""

    previous_cursor: OptionalNullable[str] = UNSET
    r"""The cursor pointing at the previous page of items."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["limit", "next_cursor", "previous_cursor"])
        nullable_fields = set(["next_cursor", "previous_cursor"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
