"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .airline import Airline, AirlineTypedDict
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class TransactionCaptureCreateTypedDict(TypedDict):
    r"""Request body for capturing an authorized transaction."""

    amount: NotRequired[Nullable[int]]
    r"""The amount to capture, in the smallest currency unit (e.g., cents). This must be less than or equal to the authorized amount, unless over-capture is available."""
    airline: NotRequired[Nullable[AirlineTypedDict]]
    r"""The airline data to submit to the payment service during the capture call."""


class TransactionCaptureCreate(BaseModel):
    r"""Request body for capturing an authorized transaction."""

    amount: OptionalNullable[int] = UNSET
    r"""The amount to capture, in the smallest currency unit (e.g., cents). This must be less than or equal to the authorized amount, unless over-capture is available."""

    airline: OptionalNullable[Airline] = UNSET
    r"""The airline data to submit to the payment service during the capture call."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["amount", "airline"])
        nullable_fields = set(["amount", "airline"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
