"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, UnrecognizedStr
from typing import Literal, Union
from typing_extensions import TypedDict


ThreeDSecureScenarioOutcomeResultTransactionStatus = Union[
    Literal[
        "Y",
        "N",
        "timeout",
    ],
    UnrecognizedStr,
]
r"""3DS result."""


class ThreeDSecureScenarioOutcomeResultTypedDict(TypedDict):
    transaction_status: ThreeDSecureScenarioOutcomeResultTransactionStatus
    r"""3DS result."""


class ThreeDSecureScenarioOutcomeResult(BaseModel):
    transaction_status: ThreeDSecureScenarioOutcomeResultTransactionStatus
    r"""3DS result."""
