"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, UnrecognizedStr
from typing import Literal, Union
from typing_extensions import TypedDict


ThreeDSecureScenarioOutcomeAuthenticationTransactionStatus = Union[
    Literal[
        "Y",
        "N",
        "A",
        "R",
        "U",
        "C",
        "timeout",
    ],
    UnrecognizedStr,
]
r"""3DS transaction status."""


class ThreeDSecureScenarioOutcomeAuthenticationTypedDict(TypedDict):
    transaction_status: ThreeDSecureScenarioOutcomeAuthenticationTransactionStatus
    r"""3DS transaction status."""


class ThreeDSecureScenarioOutcomeAuthentication(BaseModel):
    transaction_status: ThreeDSecureScenarioOutcomeAuthenticationTransactionStatus
    r"""3DS transaction status."""
