"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createsessionstatus import CreateSessionStatus
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from gr4vy.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateSessionTypedDict(TypedDict):
    r"""The session data received from the payment service."""

    status: CreateSessionStatus
    type: Literal["payment-service-session"]
    r"""Always `payment-service-session`."""
    code: NotRequired[Nullable[str]]
    r"""A generic error code that may be returned when the session could not be generated."""
    status_code: NotRequired[Nullable[int]]
    r"""The HTTP status code received from the payment service."""
    response_body: NotRequired[Nullable[Dict[str, Any]]]
    r"""The JSON response body received from the payment service."""


class CreateSession(BaseModel):
    r"""The session data received from the payment service."""

    status: CreateSessionStatus

    TYPE: Annotated[
        Annotated[
            Optional[Literal["payment-service-session"]],
            AfterValidator(validate_const("payment-service-session")),
        ],
        pydantic.Field(alias="type"),
    ] = "payment-service-session"
    r"""Always `payment-service-session`."""

    code: OptionalNullable[str] = UNSET
    r"""A generic error code that may be returned when the session could not be generated."""

    status_code: OptionalNullable[int] = UNSET
    r"""The HTTP status code received from the payment service."""

    response_body: OptionalNullable[Dict[str, Any]] = UNSET
    r"""The JSON response body received from the payment service."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["type", "code", "status_code", "response_body"])
        nullable_fields = set(["code", "status_code", "response_body"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
