"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, UNSET_SENTINEL
from gr4vy.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class PaymentMethodStoredCardTypedDict(TypedDict):
    id: str
    r"""The ID of the stored card to use."""
    method: Literal["id"]
    r"""Set to `id` to use a stored card."""


class PaymentMethodStoredCard(BaseModel):
    id: str
    r"""The ID of the stored card to use."""

    METHOD: Annotated[
        Annotated[Optional[Literal["id"]], AfterValidator(validate_const("id"))],
        pydantic.Field(alias="method"),
    ] = "id"
    r"""Set to `id` to use a stored card."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["method"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
