"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class ThreeDSecureScenarioConditionsTypedDict(TypedDict):
    first_name: NotRequired[Nullable[str]]
    r"""First name of the buyer to match."""
    last_name: NotRequired[Nullable[str]]
    r"""Last name of the buyer to match."""
    email_address: NotRequired[Nullable[str]]
    r"""Email address of the buyer to match."""
    amount: NotRequired[Nullable[int]]
    r"""Amount of the transaction to match."""
    external_identifier: NotRequired[Nullable[str]]
    r"""External identifier to match."""
    card_number: NotRequired[Nullable[str]]
    r"""Card number to match."""


class ThreeDSecureScenarioConditions(BaseModel):
    first_name: OptionalNullable[str] = UNSET
    r"""First name of the buyer to match."""

    last_name: OptionalNullable[str] = UNSET
    r"""Last name of the buyer to match."""

    email_address: OptionalNullable[str] = UNSET
    r"""Email address of the buyer to match."""

    amount: OptionalNullable[int] = UNSET
    r"""Amount of the transaction to match."""

    external_identifier: OptionalNullable[str] = UNSET
    r"""External identifier to match."""

    card_number: OptionalNullable[str] = UNSET
    r"""Card number to match."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "first_name",
                "last_name",
                "email_address",
                "amount",
                "external_identifier",
                "card_number",
            ]
        )
        nullable_fields = set(
            [
                "first_name",
                "last_name",
                "email_address",
                "amount",
                "external_identifier",
                "card_number",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
